@@ -1,6 +1,7 @@
 from sklearn.model_selection import train_test_split
 from rb.comprehension.classifiers.loader import load_file
 from sklearn.ensemble import RandomForestClassifier
+from statsmodels.stats.anova import AnovaRM
 
 
 def random_forest_classification(filepath):
@@ -12,3 +13,12 @@ def random_forest_classification(filepath):
     print(acc)
     print(clf.feature_importances_)
     return acc
+
+
+def anova_analysis(filepath):
+    df = load_file_for_anova(filepath)
+    columns = list(df.columns.values)
+    columns.remove('texts_ids')
+    columns.remove('clasa')
+    for c in columns:
+        print(f"{c}: {AnovaRM(data=df, depvar=c, subject='texts_ids', within=['clasa']).fit()}")
\ No newline at end of file
