@@ -25,6 +25,20 @@ def load_file(filename):
     return X, y
 
 
+def load_file_for_anova(filename):
+    df = pd.read_csv(filename, header=0)
+    df = df.drop("name", axis=1)
+    number_of_rows = len(df.index)
+    texts_ids = []
+    for i in range(int(number_of_rows / 2)):
+        texts_ids.append(i)
+        texts_ids.append(i)
+    print(texts_ids)
+    df['texts_ids'] = texts_ids
+    df = df.rename(columns={"class":"clasa"})
+    return df
+
+
 def build_features(columns, features, other_row, this_row):
     for column in columns:
         features.append(float(this_row[column]) / float(other_row[column]) * 100)
