@@ -10,6 +10,11 @@ class Author:
             return self.name == other.name
         return NotImplemented
 
-
     def __hash__(self):
-        return hash(tuple(self.name))
\ No newline at end of file
+        return hash(tuple(self.name))
+    
+    def __str__(self):
+        return self.name
+    
+    def __repr__(self) -> str:
+        return self.name
\ No newline at end of file
