@@ -1,11 +1,12 @@
 import os
 from rb.core.word import Word
-from typing import Dict, List
+from typing import Dict, List, Union
 
 import numpy as np
 import tensorflow as tf
 from rb import Block, Document
 from rb.core.lang import Lang
+from rb.core.text_element import TextElement
 from rb.similarity.vector import Vector
 from rb.similarity.vector_model import VectorModel, VectorModelType
 from rb.utils.rblogger import Logger
@@ -124,8 +125,15 @@ class TransformersEncoder(VectorModel):
     def encode(self, document: Document):
         vectors = []
         for block in document.get_blocks():
-            self._encode_block(block)
+            try:
+                self._encode_block(block)
+            except Exception as e:
+                logger.warning(f"Invalid characters:\n{block.text}")
             if self in block.vectors:
                 vectors.append(block.vectors[self].values)
         if vectors:
-            document.vectors[self] = Vector(np.mean(vectors, axis=0))
\ No newline at end of file
+            document.vectors[self] = Vector(np.mean(vectors, axis=0))
+            
+    def most_similar(self, elem: Union[str, TextElement, Vector], 
+                    topN: int = 10, threshold: float = None):
+        return []
\ No newline at end of file
